@@ -1,3 +1,13 @@
+/*
+	Copyright Jacques Gelinas jack@solucorp.qc.ca
+	Distributed under the Gnu Public License, see the License file
+	in this package.
+*/
+/*
+	chcontext is a wrapper to user the new_s_context system call. It
+	does little more than mapping command line option to the system call
+	arguments.
+*/
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
@@ -42,15 +52,20 @@ static void usage()
 		 "--domainname new_domainname\n"
 		 "\tSet the domainname (NIS) in the new security context.\n"
 
+		 "--flag\n"
+		 "\tSet one flag in the new or current security context. The following\n"
+		 "\tflags are supported. The option may be used several time.\n"
+		 "\n"
+		 "\tlock: The new process is trapped and can't use chcontext anymore.\n"
+		 "\tsched: The new process and its children will share a common \n"
+		 "         execution priority.\n"
+
+
 		 "--hostname new_hostname\n"
 		 "\tSet the hostname in the new security context\n"
 		 "\tThis is need because if you create a less privileged\n"
 		 "\tsecurity context, it may be unable to change its hostname\n"
 
-		 "--lock\n"
-		 "\tLock in the new context. The new process is trapped\n"
-		 "\tand can't use chcontext anymore.\n"
-
 		 "--secure\n"
 		 "\tRemove all the capabilities to make a virtual server trustable\n"
 
@@ -97,8 +112,15 @@ int main (int argc, char *argv[])
 			disconnect = 1;
 		}else if (strcmp(arg,"--silent")==0){
 			silent = 1;
-		}else if (strcmp(arg,"--lock")==0){
-			flags |= 1;
+		}else if (strcmp(arg,"--flag")==0){
+			if (strcmp(opt,"lock")==0){
+				flags |= 1;
+			}else if (strcmp(opt,"sched")==0){
+				flags |= 2;
+			}else{
+				fprintf (stderr,"Unknown flag %s\n",opt);
+			}
+			i++;
 		}else if (strcmp(arg,"--cap")==0){
 			static struct {
 				const char *option;
