@@ -1,3 +1,8 @@
+/*
+	Copyright Jacques Gelinas jack@solucorp.qc.ca
+	Distributed under the Gnu Public License, see the License file
+	in this package.
+*/
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
@@ -108,13 +113,20 @@ int main (int argc, char *argv[])
 	int i;
 	for (i=1; i<argc; i++){
 		const char *arg = argv[i];
-		// const char *opt = argv[i+1];
+		const char *opt = argv[i+1];
 		if (strcmp(arg,"--secure")==0){
 			remove = secure;
 		}else if (strcmp(arg,"--show")==0){
 			show = 1;
-		}else if (strcmp(arg,"--lock")==0){
-			flags |= 1;
+		}else if (strcmp(arg,"--flag")==0){
+			if (strcmp(opt,"lock")==0){
+				flags |= 1;
+			}else if (strcmp(opt,"sched")==0){
+				flags |= 2;
+			}else{
+				fprintf (stderr,"Unknown flag %s\n",opt);
+			}
+			i++;
 		}else if (arg[0] == '-' && arg[1] == '-'){
 			static struct {
 				const char *option;
